/**
 * @file main.c
 * @brief ::descript by user::
 * @version 0.1
 * @date {{date}}
 */

#include <stdio.h>

int main(void)
{
    printf("Program started.\\n");
    // TODO: Implement main logic
    return 0;
}
