/**
 * @file {{filename}}
 * @brief {{description}}
 * @version 0.1
 * @date {{date}}
 */

#ifndef {{include_guard}}
#define {{include_guard}}

#ifdef __cplusplus
extern "C" {
#endif

// TODO: Add function prototypes here

#ifdef __cplusplus
}
#endif

#endif // {{include_guard}}
